@@ -1772,6 +1772,31 @@ Data ranges:
         with open('tests/files/elf.s19', 'r') as fin:
             self.assertEqual(bf.as_srec(), fin.read())
 
+    def test_add_elf_blinky(self):
+        bf = bincopy.BinFile()
+        bf.add_elf_file('tests/files/evkbimxrt1050_iled_blinky_sdram.axf')
+        actual_srec = bf.as_srec()
+
+        bf = bincopy.BinFile()
+        bf.add_srec_file('tests/files/evkbimxrt1050_iled_blinky_sdram.s19')
+        expected_srec = bf.as_srec()
+
+        self.assertEqual(actual_srec, expected_srec)
+
+    def test_add_elf_gcc(self):
+        bf = bincopy.BinFile()
+        bf.add_elf_file('tests/files/elf/gcc.elf')
+
+        with open('tests/files/elf/gcc.bin', 'rb') as fin:
+            self.assertEqual(bf.as_binary(), fin.read())
+
+    def test_add_elf_iar(self):
+        bf = bincopy.BinFile()
+        bf.add_elf_file('tests/files/elf/iar.out')
+
+        with open('tests/files/elf/iar.bin', 'rb') as fin:
+            self.assertEqual(bf.as_binary(), fin.read())
+
     def test_exclude_edge_cases(self):
         binfile = bincopy.BinFile()
         binfile.add_binary(b'1234', address=10)
